clear all

m = 1;
d = 0.3;
k = 1000;

M = [m 0 0;
     0 m 0;
     0 0 m];
 
D = [2*d -d   0;
     -d  2*d -d;
      0  -d   d];
 
K = [2*k -k   0;
     -k  2*k -k;
      0  -k   k];

OMEGA = 0:0.01:12;

for i=1:length(OMEGA),
    w = OMEGA(i)*2*pi;
    H = inv(-(w^2)*M + sqrt(-1)*w*D + K);
    
    H13(i) = H(1,3);
    H23(i) = H(2,3);
    H33(i) = H(3,3);
    
end

idx = [1:10:221 222:230 231:10:621 622:640 641:10:901 902:920 921:10:length(OMEGA)];

for n=1:length(idx),
    i = idx(n);
    
    subplot(8,1,1),
    semilogy(OMEGA,abs(H13),'linewidth',2)
    ylabel('|H_{13}|')
    axis([0 12 1e-5 1])
    hold on
    text(0.2,0.1,'Massa 1','color','b')
    semilogy(OMEGA(i)*ones(2,1),[1e-5 1],'r-')
    hold off
    
    subplot(8,1,2),
    plot(OMEGA,angle(H13)*180/pi,'linewidth',2)
    ylabel('f_{13}','fontname','symbol')
    axis([0 12 -180 180])
    hold on
    plot(OMEGA(i)*ones(2,1),[-180 180],'r-')
    hold off
        
    subplot(8,1,3),
    semilogy(OMEGA,abs(H23),'g-','linewidth',2,'color',[0 0.8 0])
    axis([0 12 1e-5 1])
    ylabel('|H_{23}|')
    hold on
    text(0.2,0.1,'Massa 2','color',[0 0.8 0])
    semilogy(OMEGA(i)*ones(2,1),[1e-5 1],'r-')
    hold off
    
    subplot(8,1,4),
    plot(OMEGA,angle(H23)*180/pi,'g-','linewidth',2,'color',[0 0.8 0])
    ylabel('f_{23}','fontname','symbol')
    axis([0 12 -180 180])
    hold on
    plot(OMEGA(i)*ones(2,1),[-180 180],'r-')
    hold off
        
    subplot(8,1,5),
    semilogy(OMEGA,abs(H33),'r-','linewidth',2,'color',[0.8 0 0])
    axis([0 12 1e-5 1])
    ylabel('|H_{33}|')
    hold on
    text(0.2,0.1,'Massa 3','color',[0.8 0 0])
    semilogy(OMEGA(i)*ones(2,1),[1e-5 1],'r-')
    hold off
    
    subplot(8,1,6),
    plot(OMEGA,angle(H33)*180/pi,'r-','linewidth',2,'color',[0.8 0 0])
    ylabel('f_{33}','fontname','symbol')
    axis([0 12 -180 180])
    hold on
    plot(OMEGA(i)*ones(2,1),[-180 180],'r-')
    hold off
    
    t = 0:0.1:0.9;
    A = 10;
    for j=1:10,
        x1 = A*abs(H13(i))*sin(2*pi*t(j) - angle(H13(i)));
        x13 = [x1-0.05 x1+0.05 x1+0.05 x1-0.05 x1-0.05];
        x2 = A*abs(H23(i))*sin(2*pi*t(j) - angle(H23(i)));
        x23 = [x2-0.05 x2+0.05 x2+0.05 x2-0.05 x2-0.05];
        x3 = A*abs(H33(i))*sin(2*pi*t(j) - angle(H33(i)));
        x33 = [x3-0.05 x3+0.05 x3+0.05 x3-0.05 x3-0.05];
        f = 0.2*sin(2*pi*t(j));
        
        subplot(8,1,[7 8]), plot([x3 x3+f],[0.3 0.3],'r-d','linewidth',3,'markerfacecolor','r')
        axis([-1 1 0 0.4])
        hold on
        fill(x13,[0.08 0.08 0.12 0.12 0.08],'k')
        fill(x23,[0.18 0.18 0.22 0.22 0.18],'k')
        fill(x33,[0.28 0.28 0.32 0.32 0.28],'k')
        plot([0 x1 x2 x3],0:0.1:0.3,'k--','linewidth',2)
        hold off
        pause(0.1)
    end
end
